@@ -155,8 +155,8 @@ QString InvoiceOperations::buildFolderName(
     bool /* reviewed */,
     const QString & /* comment */)
 {
-    QString cleanSender = QString(sender).replace(" ", "_");
-    QString cleanInvoiceNumber = QString(invoiceNumber).replace(" ", "_");
+    QString cleanSender = QString(sender).replace(" ", "-").replace("/", "-").replace("\\", "-");
+    QString cleanInvoiceNumber = QString(invoiceNumber).replace(" ", "-").replace("/", "-").replace("\\", "-");
 
     return QString("%1_%2_%3_%4_%5")
         .arg(date)
@@ -219,7 +219,7 @@ bool InvoiceOperations::invoiceNumberExists(const QString &targetBasePath, const
         return false;
     }
 
-    QString cleanInvoiceNumber = QString(invoiceNumber).replace(" ", "_");
+    QString cleanInvoiceNumber = QString(invoiceNumber).replace(" ", "-");
     QDir dir(targetBasePath);
 
     if (!dir.exists()) {
@@ -338,6 +338,35 @@ bool InvoiceOperations::updateInvoiceMetadata(
         return false;
     }
 
+    // Load old values for change logging
+    QSettings oldSettings(directoryFilePath, QSettings::IniFormat);
+    QStringList changes;
+
+    oldSettings.beginGroup("invoice");
+    QString oldReceiptDate = oldSettings.value("ReceiptDate", "").toString();
+    QString oldIssueDate = oldSettings.value("IssueDate", "").toString();
+    QString oldSeller = oldSettings.value("Seller", "").toString();
+    QString oldId = oldSettings.value("ID", "").toString();
+    QString oldBudgetCode = oldSettings.value("BuyerReference", "").toString();
+    QString oldAmount = oldSettings.value("PayableAmount", "").toString();
+    oldSettings.endGroup();
+
+    oldSettings.beginGroup("processing");
+    bool oldReviewed = oldSettings.value("Reviewed", "false").toString() == "true";
+    QString oldNote = oldSettings.value("Note", "").toString();
+    oldSettings.endGroup();
+
+    // Detect changes
+    if (oldReceiptDate != receiptStamp) changes << QString("ReceiptDate: %1 -> %2").arg(oldReceiptDate, receiptStamp);
+    if (oldIssueDate != date) changes << QString("IssueDate: %1 -> %2").arg(oldIssueDate, date);
+    if (oldSeller != sender) changes << QString("Seller: %1 -> %2").arg(oldSeller, sender);
+    if (oldId != invoiceNumber) changes << QString("ID: %1 -> %2").arg(oldId, invoiceNumber);
+    if (oldBudgetCode != budgetCode) changes << QString("BuyerReference: %1 -> %2").arg(oldBudgetCode, budgetCode);
+    if (oldAmount != amount) changes << QString("PayableAmount: %1 -> %2").arg(oldAmount, amount);
+    if (oldReviewed != reviewed) changes << QString("Reviewed: %1 -> %2").arg(oldReviewed ? "true" : "false", reviewed ? "true" : "false");
+    if (oldNote != comment) changes << QString("Note: %1 -> %2").arg(oldNote, comment);
+
+    // Write new values
     QFile directoryFile(directoryFilePath);
     if (!directoryFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
         return false;
@@ -345,7 +374,7 @@ bool InvoiceOperations::updateInvoiceMetadata(
 
     QTextStream out(&directoryFile);
 
-    // Desktop Entry section (freedesktop.org standard -> FIX: KDE Standard? -> Should be readable by interested applications...)
+    // Desktop Entry section (freedesktop.org standard)
     out << "[Desktop Entry]\n";
     out << "Type=Directory\n";
     out << "Icon=" << folderIcon << "\n";
@@ -375,8 +404,8 @@ bool InvoiceOperations::updateInvoiceMetadata(
 
     directoryFile.close();
 
-    // Append to existing workflow log
-    workflowLogger.appendToLog(folderPath, user);
+    // Append changes to existing workflow log
+    workflowLogger.appendToLogWithChanges(folderPath, user, changes);
 
     return true;
 }
